@@ -10,11 +10,11 @@ import importlib
 import inspect
 import os
 import pathlib
-import pkg_resources
 import sys
 
-from understory import mkdn
-from understory import solarized
+import pkg_resources
+
+from understory import mkdn, solarized
 
 from . import parse
 
