@@ -11,45 +11,25 @@ Simple interface, simple deploy.
 
 """
 
-# TODO tidy up these imports
-
+import pendulum
 from dns import resolver as dns
 from hstspreload import in_hsts_preload
-import pendulum  # TODO XXX
 from requests.exceptions import ConnectionError
 
-from understory import mf
+from understory import mf, mm
 from understory.mkdn import render as mkdn
-from understory import mm
 from understory.mm import Template as template  # noqa
 from understory.mm import templates  # noqa
 from understory.uri import parse as uri
 
-from . import agent
+from . import agent, braid, framework
 from .agent import *  # noqa
-from . import braid
 from .braid import *  # noqa
-from . import framework
 from .framework import *  # noqa
-from .indie import *  # noqa
-from .response import (
-    Status,  # noqa
-    OK,
-    Created,
-    Accepted,
-    NoContent,
-    MultiStatus,
-    Found,
-    SeeOther,
-    PermanentRedirect,
-    BadRequest,
-    Unauthorized,
-    Forbidden,
-    NotFound,
-    MethodNotAllowed,
-    Conflict,
-    Gone,
-)
+from .response import Status  # noqa
+from .response import (OK, Accepted, BadRequest, Conflict, Created, Forbidden,
+                       Found, Gone, MethodNotAllowed, MultiStatus, NoContent,
+                       NotFound, PermanentRedirect, SeeOther, Unauthorized)
 
 # from .tasks import run_queue
 
