@@ -1,9 +1,9 @@
 """."""
 
 import datetime
+import io
 import json
 import re
-import io
 import time
 
 import lxml.html
@@ -13,16 +13,11 @@ import pyvirtualdisplay
 import requests
 import selenium
 from selenium import webdriver
-from selenium.webdriver.common.by import By
 from selenium.webdriver.common.action_chains import ActionChains
+from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions
 from selenium.webdriver.support.ui import WebDriverWait
-
-from understory import mf
-from understory import solarized
-from understory import sql
-from understory import uri
-from understory import web
+from understory import mf, solarized, sql, uri, web
 
 __all__ = [
     "post",
@@ -315,33 +310,33 @@ def parse(html):
     return Document(html)
 
 
-def apply_dns(url):
-    if url.startswith("/"):
-        return url
-    url = uri.parse(url)
-    if url.host == "alice.example":
-        url = str(url).replace("http://alice.example", "http://127.0.0.1:8080")
-    elif url.host == "bob.example":
-        url = str(url).replace("http://bob.example", "http://127.0.0.1:8081")
-    elif url.host == "hello.example":
-        url = str(url).replace("http://hello.example", "http://127.0.0.1:8082")
-    else:
-        url = str(url)
-    return url
+# XXX def apply_dns(url):
+# XXX     if url.startswith("/"):
+# XXX         return url
+# XXX     url = uri.parse(url)
+# XXX     if url.host == "alice.example":
+# XXX         url = str(url).replace("http://alice.example", "http://127.0.0.1:8080")
+# XXX     elif url.host == "bob.example":
+# XXX         url = str(url).replace("http://bob.example", "http://127.0.0.1:8081")
+# XXX     elif url.host == "hello.example":
+# XXX         url = str(url).replace("http://hello.example", "http://127.0.0.1:8082")
+# XXX     else:
+# XXX         url = str(url)
+# XXX     return url
 
 
-def unapply_dns(url):
-    url = uri.parse(url)
-    if url.host == "127.0.0.1":
-        if url.port == 8080:
-            url = str(url).replace("http://127.0.0.1:8080", "http://alice.example")
-        elif url.port == 8081:
-            url = str(url).replace("http://127.0.0.1:8081", "http://bob.example")
-        elif url.port == 8082:
-            url = str(url).replace("http://127.0.0.1:8082", "http://hello.example")
-    else:
-        url = str(url)
-    return url
+# XXX def unapply_dns(url):
+# XXX     url = uri.parse(url)
+# XXX     if url.host == "127.0.0.1":
+# XXX         if url.port == 8080:
+# XXX             url = str(url).replace("http://127.0.0.1:8080", "http://alice.example")
+# XXX         elif url.port == 8081:
+# XXX             url = str(url).replace("http://127.0.0.1:8081", "http://bob.example")
+# XXX         elif url.port == 8082:
+# XXX             url = str(url).replace("http://127.0.0.1:8082", "http://hello.example")
+# XXX     else:
+# XXX         url = str(url)
+# XXX     return url
 
 
 class Document:
@@ -469,7 +464,7 @@ class Firefox:
             url = args[0]
         elif len(args) == 2:
             url = "/".join(args)
-        url = apply_dns(url)
+        # XXX url = apply_dns(url)
         self.browser.get(url)
         if wait:
             time.sleep(wait)
@@ -483,7 +478,8 @@ class Firefox:
             wait.until(condition)
 
     def wait_until_url_contains(self, url):
-        self.wait(self.EC.url_contains(apply_dns(url)))
+        # XXX self.wait(self.EC.url_contains(apply_dns(url)))
+        self.wait(self.EC.url_contains(url))
 
     def select(self, selector):
         return self.browser.find_elements_by_css_selector(selector)
