@@ -14,15 +14,12 @@ a Pythonic API.
 
 from __future__ import annotations
 
-from base64 import b64encode, b64decode
 import collections
-
 # import errno
 import getpass
 import hashlib
 import inspect
 import os
-import pkg_resources
 import pathlib
 import pprint
 import re
@@ -31,49 +28,33 @@ import shutil
 import signal
 import sys
 import time
-from time import sleep
 import urllib
+import warnings  # mf2py's beautifulsoup's unspecified parser -- force lxml?
+from base64 import b64decode, b64encode
+from time import sleep
 
 import Crypto.Random.random
 import gevent.pywsgi
 import pendulum
+import pkg_resources
 import sh
 import unidecode
 import watchdog.events
 import watchdog.observers
-
-from understory import kv
-from understory import mm
-from understory.mm import Template
-from understory import sql
 from understory import term  # noqa NOTE to colorize print()
+from understory import kv, mm, sql
+from understory.mm import Template
 
-from ..agent import parse, apply_dns, cache
-from ..response import (
-    Status,  # noqa
-    OK,
-    Created,
-    Accepted,
-    NoContent,
-    MultiStatus,
-    Subscription,
-    Found,
-    SeeOther,
-    PermanentRedirect,
-    BadRequest,
-    Unauthorized,
-    Forbidden,
-    NotFound,
-    MethodNotAllowed,
-    Conflict,
-    Gone,
-)
+from ..agent import cache, parse
+from ..response import Status  # noqa
+from ..response import (OK, Accepted, BadRequest, Conflict, Created, Forbidden,
+                        Found, Gone, MethodNotAllowed, MultiStatus, NoContent,
+                        NotFound, PermanentRedirect, SeeOther, Subscription,
+                        Unauthorized)
 from .letsencrypt import generate_cert
-from .newmath import nbencode, nbdecode, nbrandom, nb60_re
+from .newmath import nb60_re, nbdecode, nbencode, nbrandom
 from .passphrases import generate_passphrase, verify_passphrase
-from .util import tx, header, json, JSONEncoder, shift_headings
-
-import warnings  # mf2py's beautifulsoup's unspecified parser -- force lxml?
+from .util import JSONEncoder, header, json, shift_headings, tx
 
 warnings.simplefilter("ignore")
 
@@ -968,7 +949,7 @@ class Application:
             if exc.code == 201:
                 tx.response.headers.location = exc.location
             elif exc.code in (301, 302, 303, 307, 308):
-                redirect_uri = apply_dns(str(tx.response.body))
+                redirect_uri = str(tx.response.body)  # XXX remove apply_dns
                 if redirect_uri.startswith("/"):  # relative HTTP(S) URL
                     tx.response.headers.location = urllib.parse.quote(redirect_uri)
                 else:  # anything else (moz-extension, etc..)
